==> ejc-zdscost-impl-3.0.0-20250801.082300-102-sources.jar: com/ejianc/business/zdscost/bean/BudgetProjectDetailChangeEntity.java <==
package com.ejianc.business.zdscost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 切包清单变更-明细
 *
 * @author generator
 *
 */
@TableName("ejc_budget_project_detail_change")
public class BudgetProjectDetailChangeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "budget_id")
    private Long budgetId; // 主表主键
    @TableField(value = "pack_up_id")
    private Long packUpId; // 上包清单id
    @TableField(value = "material_list_id")
    private Long materialListId; // 下包材料清单id
    @TableField(value = "engineering_list_id")
    private Long engineeringListId; // 下包工程清单id
    @TableField(value = "pack_up_flag")
    private Integer packUpFlag; // 是否上包清单，1是0否
    @TableField(value = "material_list_flag")
    private Integer materialListFlag; // 是否材料清单，1是0否
    @TableField(value = "engineering_list_flag")
    private Integer engineeringListFlag; // 是否工程清单，1是0否
    @TableField(value = "code")
    private String code; // 上包清单-项目编码
    @TableField(value = "name")
    private String name; // 上包清单-项目名称
    @TableField(value = "feature")
    private String feature; // 上包清单-项目特征
    @TableField(value = "unit")
    private String unit; // 上包清单-计量单位
    @TableField(value = "contract_num")
    private BigDecimal contractNum; // 上包工程量-上包合同量
    @TableField(value = "check_engineering_num")
    private BigDecimal checkEngineeringNum; // 上包工程量-投标复核工程量
    @TableField(value = "material_price")
    private BigDecimal materialPrice; // 上包合同价-上包材料单价
    @TableField(value = "fix_price")
    private BigDecimal fixPrice; // 上包合同价-上包安装单价
    @TableField(value = "price")
    private BigDecimal price; // 上包合同价-上包综合单价
    @TableField(value = "money")
    private BigDecimal money; // 上包合同价-上包合价
    @TableField(value = "big_pack_sid")
    private String bigPackSid; // 切包情况-erp大包id
    @TableField(value = "big_pack_id")
    private Long bigPackId; // 切包情况-大包id
    @TableField(value = "big_pack_code")
    private String bigPackCode; // 切包情况-大包编码
    @TableField(value = "big_pack_name")
    private String bigPackName; // 切包情况-大包名称
    @TableField(value = "puchase_flag")
    private String puchaseFlag; // 切包情况-是否公司采购，1是0否
    @TableField(value = "material_pack_sid")
    private String materialPackSid; // 切包情况-erp材料包id
    @TableField(value = "material_pack_id")
    private Long materialPackId; // 切包情况-材料包id，二级物料类别
    @TableField(value = "material_pack_code")
    private String materialPackCode; // 切包情况-材料包编码
    @TableField(value = "material_pack_name")
    private String materialPackName; // 切包情况-材料包名称
    @TableField(value = "engineering_pack_id")
    private Long engineeringPackId; // 切包情况-erp工程包id
    @TableField(value = "engineering_pack_sid")
    private String engineeringPackSid; // 切包情况-工程包id，分包领料范围
    @TableField(value = "engineering_pack_code")
    private String engineeringPackCode; // 切包情况-工程包编码
    @TableField(value = "engineering_pack_name")
    private String engineeringPackName; // 切包情况-工程包名称
    @TableField(value = "item_code")
    private String itemCode; // 下包清单-项目编码
    @TableField(value = "item_name")
    private String itemName; // 下包清单-项目名称
    @TableField(value = "item_feature")
    private String itemFeature; // 下包清单-项目特征
    @TableField(value = "item_unit")
    private String itemUnit; // 下包清单-单位
    @TableField(value = "item_num")
    private BigDecimal itemNum; // 下包清单-进场二次点量
    @TableField(value = "upper_material_price")
    private BigDecimal upperMaterialPrice; // 上限价-上限材料单价
    @TableField(value = "upper_fix_price")
    private BigDecimal upperFixPrice; // 上限价-上限安装单价
    @TableField(value = "upper_price")
    private BigDecimal upperPrice; // 上限价-上限综合单价
    @TableField(value = "upper_money")
    private BigDecimal upperMoney; // 上限价-上限合价
    @TableField(value = "change_id")
    private Long changeId; // 变更主键
    @TableField(value = "change_bid")
    private Long changeBid; // 变更子表主键

    /**
     * 变更类型
     */
    @TableField(value = "change_type")
    private String changeType;

    @TableField(value = "mate_type")
    private String mateType; // 匹配类型：4-待识别，0-不匹配，1-部分匹配，2-完全匹配，3-识别失败
    @TableField(value = "material_id")
    private Long materialId; // 物料Id
    @TableField(value = "material_code")
    private String materialCode; // 物料编码
    @TableField(value = "material_name")
    private String materialName; // 物料名称
    @TableField(value = "material_spec")
    private String materialSpec; // 物料属性

    @TableField(value = "sequen")
    private Integer sequen; // 排序字段

    public Integer getSequen() {
        return sequen;
    }

    public void setSequen(Integer sequen) {
        this.sequen = sequen;
    }

    public String getMateType() {
        return mateType;
    }

    public void setMateType(String mateType) {
        this.mateType = mateType;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }


    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public Long getPackUpId() {
        return packUpId;
    }

    public void setPackUpId(Long packUpId) {
        this.packUpId = packUpId;
    }

    public Long getMaterialListId() {
        return materialListId;
    }

    public void setMaterialListId(Long materialListId) {
        this.materialListId = materialListId;
    }

    public Long getEngineeringListId() {
        return engineeringListId;
    }

    public void setEngineeringListId(Long engineeringListId) {
        this.engineeringListId = engineeringListId;
    }

    public Integer getPackUpFlag() {
        return packUpFlag;
    }

    public void setPackUpFlag(Integer packUpFlag) {
        this.packUpFlag = packUpFlag;
    }

    public Integer getMaterialListFlag() {
        return materialListFlag;
    }

    public void setMaterialListFlag(Integer materialListFlag) {
        this.materialListFlag = materialListFlag;
    }

    public Integer getEngineeringListFlag() {
        return engineeringListFlag;
    }

    public void setEngineeringListFlag(Integer engineeringListFlag) {
        this.engineeringListFlag = engineeringListFlag;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getFeature() {
        return feature;
    }

    public void setFeature(String feature) {
        this.feature = feature;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }

    public BigDecimal getCheckEngineeringNum() {
        return checkEngineeringNum;
    }

    public void setCheckEngineeringNum(BigDecimal checkEngineeringNum) {
        this.checkEngineeringNum = checkEngineeringNum;
    }

    public BigDecimal getMaterialPrice() {
        return materialPrice;
    }

    public void setMaterialPrice(BigDecimal materialPrice) {
        this.materialPrice = materialPrice;
    }

    public BigDecimal getFixPrice() {
        return fixPrice;
    }

    public void setFixPrice(BigDecimal fixPrice) {
        this.fixPrice = fixPrice;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public String getBigPackSid() {
        return bigPackSid;
    }

    public void setBigPackSid(String bigPackSid) {
        this.bigPackSid = bigPackSid;
    }

    public Long getBigPackId() {
        return bigPackId;
    }

    public void setBigPackId(Long bigPackId) {
        this.bigPackId = bigPackId;
    }

    public String getBigPackCode() {
        return bigPackCode;
    }

    public void setBigPackCode(String bigPackCode) {
        this.bigPackCode = bigPackCode;
    }

    public String getBigPackName() {
        return bigPackName;
    }

    public void setBigPackName(String bigPackName) {
        this.bigPackName = bigPackName;
    }

    public String getPuchaseFlag() {
        return puchaseFlag;
    }

    public void setPuchaseFlag(String puchaseFlag) {
        this.puchaseFlag = puchaseFlag;
    }

    public String getMaterialPackSid() {
        return materialPackSid;
    }

    public void setMaterialPackSid(String materialPackSid) {
        this.materialPackSid = materialPackSid;
    }

    public Long getMaterialPackId() {
        return materialPackId;
    }

    public void setMaterialPackId(Long materialPackId) {
        this.materialPackId = materialPackId;
    }

    public String getMaterialPackCode() {
        return materialPackCode;
    }

    public void setMaterialPackCode(String materialPackCode) {
        this.materialPackCode = materialPackCode;
    }

    public String getMaterialPackName() {
        return materialPackName;
    }

    public void setMaterialPackName(String materialPackName) {
        this.materialPackName = materialPackName;
    }

    public Long getEngineeringPackId() {
        return engineeringPackId;
    }

    public void setEngineeringPackId(Long engineeringPackId) {
        this.engineeringPackId = engineeringPackId;
    }

    public String getEngineeringPackSid() {
        return engineeringPackSid;
    }

    public void setEngineeringPackSid(String engineeringPackSid) {
        this.engineeringPackSid = engineeringPackSid;
    }

    public String getEngineeringPackCode() {
        return engineeringPackCode;
    }

    public void setEngineeringPackCode(String engineeringPackCode) {
        this.engineeringPackCode = engineeringPackCode;
    }

    public String getEngineeringPackName() {
        return engineeringPackName;
    }

    public void setEngineeringPackName(String engineeringPackName) {
        this.engineeringPackName = engineeringPackName;
    }

    public String getItemCode() {
        return itemCode;
    }

    public void setItemCode(String itemCode) {
        this.itemCode = itemCode;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getItemFeature() {
        return itemFeature;
    }

    public void setItemFeature(String itemFeature) {
        this.itemFeature = itemFeature;
    }

    public String getItemUnit() {
        return itemUnit;
    }

    public void setItemUnit(String itemUnit) {
        this.itemUnit = itemUnit;
    }

    public BigDecimal getItemNum() {
        return itemNum;
    }

    public void setItemNum(BigDecimal itemNum) {
        this.itemNum = itemNum;
    }

    public BigDecimal getUpperMaterialPrice() {
        return upperMaterialPrice;
    }

    public void setUpperMaterialPrice(BigDecimal upperMaterialPrice) {
        this.upperMaterialPrice = upperMaterialPrice;
    }

    public BigDecimal getUpperFixPrice() {
        return upperFixPrice;
    }

    public void setUpperFixPrice(BigDecimal upperFixPrice) {
        this.upperFixPrice = upperFixPrice;
    }

    public BigDecimal getUpperPrice() {
        return upperPrice;
    }

    public void setUpperPrice(BigDecimal upperPrice) {
        this.upperPrice = upperPrice;
    }

    public BigDecimal getUpperMoney() {
        return upperMoney;
    }

    public void setUpperMoney(BigDecimal upperMoney) {
        this.upperMoney = upperMoney;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

}

==> ejc-zdscost-impl-3.0.0-20250814.023350-118-sources.jar: com/ejianc/business/zdscost/bean/BudgetProjectDetailChangeEntity.java <==
package com.ejianc.business.zdscost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 切包清单变更-明细
 *
 * @author generator
 *
 */
@TableName("ejc_budget_project_detail_change")
public class BudgetProjectDetailChangeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "budget_id")
    private Long budgetId; // 主表主键
    @TableField(value = "pack_up_id")
    private Long packUpId; // 上包清单id
    @TableField(value = "material_list_id")
    private Long materialListId; // 下包材料清单id
    @TableField(value = "engineering_list_id")
    private Long engineeringListId; // 下包工程清单id
    @TableField(value = "pack_up_flag")
    private Integer packUpFlag; // 是否上包清单，1是0否
    @TableField(value = "material_list_flag")
    private Integer materialListFlag; // 是否材料清单，1是0否
    @TableField(value = "engineering_list_flag")
    private Integer engineeringListFlag; // 是否工程清单，1是0否
    @TableField(value = "code")
    private String code; // 上包清单-项目编码
    @TableField(value = "name")
    private String name; // 上包清单-项目名称
    @TableField(value = "feature")
    private String feature; // 上包清单-项目特征
    @TableField(value = "unit")
    private String unit; // 上包清单-计量单位
    @TableField(value = "contract_num")
    private BigDecimal contractNum; // 上包工程量-上包合同量
    @TableField(value = "check_engineering_num")
    private BigDecimal checkEngineeringNum; // 上包工程量-投标复核工程量
    @TableField(value = "material_price")
    private BigDecimal materialPrice; // 上包合同价-上包材料单价
    @TableField(value = "fix_price")
    private BigDecimal fixPrice; // 上包合同价-上包安装单价
    @TableField(value = "price")
    private BigDecimal price; // 上包合同价-上包综合单价
    @TableField(value = "money")
    private BigDecimal money; // 上包合同价-上包合价
    @TableField(value = "big_pack_sid")
    private String bigPackSid; // 切包情况-erp大包id
    @TableField(value = "big_pack_id")
    private Long bigPackId; // 切包情况-大包id
    @TableField(value = "big_pack_code")
    private String bigPackCode; // 切包情况-大包编码
    @TableField(value = "big_pack_name")
    private String bigPackName; // 切包情况-大包名称
    @TableField(value = "puchase_flag")
    private String puchaseFlag; // 切包情况-是否公司采购，1是0否
    @TableField(value = "material_pack_sid")
    private String materialPackSid; // 切包情况-erp材料包id
    @TableField(value = "material_pack_id")
    private Long materialPackId; // 切包情况-材料包id，二级物料类别
    @TableField(value = "material_pack_code")
    private String materialPackCode; // 切包情况-材料包编码
    @TableField(value = "material_pack_name")
    private String materialPackName; // 切包情况-材料包名称
    @TableField(value = "engineering_pack_id")
    private Long engineeringPackId; // 切包情况-erp工程包id
    @TableField(value = "engineering_pack_sid")
    private String engineeringPackSid; // 切包情况-工程包id，分包领料范围
    @TableField(value = "engineering_pack_code")
    private String engineeringPackCode; // 切包情况-工程包编码
    @TableField(value = "engineering_pack_name")
    private String engineeringPackName; // 切包情况-工程包名称
    @TableField(value = "item_code")
    private String itemCode; // 下包清单-项目编码
    @TableField(value = "item_name")
    private String itemName; // 下包清单-项目名称
    @TableField(value = "item_feature")
    private String itemFeature; // 下包清单-项目特征
    @TableField(value = "item_unit")
    private String itemUnit; // 下包清单-单位
    @TableField(value = "item_num")
    private BigDecimal itemNum; // 下包清单-进场二次点量
    @TableField(value = "upper_material_price")
    private BigDecimal upperMaterialPrice; // 上限价-上限材料单价
    @TableField(value = "upper_fix_price")
    private BigDecimal upperFixPrice; // 上限价-上限安装单价
    @TableField(value = "upper_price")
    private BigDecimal upperPrice; // 上限价-上限综合单价
    @TableField(value = "upper_money")
    private BigDecimal upperMoney; // 上限价-上限合价
    @TableField(value = "change_id")
    private Long changeId; // 变更主键
    @TableField(value = "change_bid")
    private Long changeBid; // 变更子表主键

    /**
     * 变更类型
     */
    @TableField(value = "change_type")
    private String changeType;

    @TableField(value = "mate_type")
    private String mateType; // 匹配类型：4-待识别，0-不匹配，1-部分匹配，2-完全匹配，3-识别失败
    @TableField(value = "material_id")
    private Long materialId; // 物料Id
    @TableField(value = "material_code")
    private String materialCode; // 物料编码
    @TableField(value = "material_name")
    private String materialName; // 物料名称
    @TableField(value = "material_spec")
    private String materialSpec; // 物料属性

    @TableField(value = "sequen")
    private BigDecimal sequen; // 排序字段

    public BigDecimal getSequen() {
        return sequen;
    }

    public void setSequen(BigDecimal sequen) {
        this.sequen = sequen;
    }

    public String getMateType() {
        return mateType;
    }

    public void setMateType(String mateType) {
        this.mateType = mateType;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }

    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }


    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public Long getPackUpId() {
        return packUpId;
    }

    public void setPackUpId(Long packUpId) {
        this.packUpId = packUpId;
    }

    public Long getMaterialListId() {
        return materialListId;
    }

    public void setMaterialListId(Long materialListId) {
        this.materialListId = materialListId;
    }

    public Long getEngineeringListId() {
        return engineeringListId;
    }

    public void setEngineeringListId(Long engineeringListId) {
        this.engineeringListId = engineeringListId;
    }

    public Integer getPackUpFlag() {
        return packUpFlag;
    }

    public void setPackUpFlag(Integer packUpFlag) {
        this.packUpFlag = packUpFlag;
    }

    public Integer getMaterialListFlag() {
        return materialListFlag;
    }

    public void setMaterialListFlag(Integer materialListFlag) {
        this.materialListFlag = materialListFlag;
    }

    public Integer getEngineeringListFlag() {
        return engineeringListFlag;
    }

    public void setEngineeringListFlag(Integer engineeringListFlag) {
        this.engineeringListFlag = engineeringListFlag;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getFeature() {
        return feature;
    }

    public void setFeature(String feature) {
        this.feature = feature;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getContractNum() {
        return contractNum;
    }

    public void setContractNum(BigDecimal contractNum) {
        this.contractNum = contractNum;
    }

    public BigDecimal getCheckEngineeringNum() {
        return checkEngineeringNum;
    }

    public void setCheckEngineeringNum(BigDecimal checkEngineeringNum) {
        this.checkEngineeringNum = checkEngineeringNum;
    }

    public BigDecimal getMaterialPrice() {
        return materialPrice;
    }

    public void setMaterialPrice(BigDecimal materialPrice) {
        this.materialPrice = materialPrice;
    }

    public BigDecimal getFixPrice() {
        return fixPrice;
    }

    public void setFixPrice(BigDecimal fixPrice) {
        this.fixPrice = fixPrice;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }

    public String getBigPackSid() {
        return bigPackSid;
    }

    public void setBigPackSid(String bigPackSid) {
        this.bigPackSid = bigPackSid;
    }

    public Long getBigPackId() {
        return bigPackId;
    }

    public void setBigPackId(Long bigPackId) {
        this.bigPackId = bigPackId;
    }

    public String getBigPackCode() {
        return bigPackCode;
    }

    public void setBigPackCode(String bigPackCode) {
        this.bigPackCode = bigPackCode;
    }

    public String getBigPackName() {
        return bigPackName;
    }

    public void setBigPackName(String bigPackName) {
        this.bigPackName = bigPackName;
    }

    public String getPuchaseFlag() {
        return puchaseFlag;
    }

    public void setPuchaseFlag(String puchaseFlag) {
        this.puchaseFlag = puchaseFlag;
    }

    public String getMaterialPackSid() {
        return materialPackSid;
    }

    public void setMaterialPackSid(String materialPackSid) {
        this.materialPackSid = materialPackSid;
    }

    public Long getMaterialPackId() {
        return materialPackId;
    }

    public void setMaterialPackId(Long materialPackId) {
        this.materialPackId = materialPackId;
    }

    public String getMaterialPackCode() {
        return materialPackCode;
    }

    public void setMaterialPackCode(String materialPackCode) {
        this.materialPackCode = materialPackCode;
    }

    public String getMaterialPackName() {
        return materialPackName;
    }

    public void setMaterialPackName(String materialPackName) {
        this.materialPackName = materialPackName;
    }

    public Long getEngineeringPackId() {
        return engineeringPackId;
    }

    public void setEngineeringPackId(Long engineeringPackId) {
        this.engineeringPackId = engineeringPackId;
    }

    public String getEngineeringPackSid() {
        return engineeringPackSid;
    }

    public void setEngineeringPackSid(String engineeringPackSid) {
        this.engineeringPackSid = engineeringPackSid;
    }

    public String getEngineeringPackCode() {
        return engineeringPackCode;
    }

    public void setEngineeringPackCode(String engineeringPackCode) {
        this.engineeringPackCode = engineeringPackCode;
    }

    public String getEngineeringPackName() {
        return engineeringPackName;
    }

    public void setEngineeringPackName(String engineeringPackName) {
        this.engineeringPackName = engineeringPackName;
    }

    public String getItemCode() {
        return itemCode;
    }

    public void setItemCode(String itemCode) {
        this.itemCode = itemCode;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public String getItemFeature() {
        return itemFeature;
    }

    public void setItemFeature(String itemFeature) {
        this.itemFeature = itemFeature;
    }

    public String getItemUnit() {
        return itemUnit;
    }

    public void setItemUnit(String itemUnit) {
        this.itemUnit = itemUnit;
    }

    public BigDecimal getItemNum() {
        return itemNum;
    }

    public void setItemNum(BigDecimal itemNum) {
        this.itemNum = itemNum;
    }

    public BigDecimal getUpperMaterialPrice() {
        return upperMaterialPrice;
    }

    public void setUpperMaterialPrice(BigDecimal upperMaterialPrice) {
        this.upperMaterialPrice = upperMaterialPrice;
    }

    public BigDecimal getUpperFixPrice() {
        return upperFixPrice;
    }

    public void setUpperFixPrice(BigDecimal upperFixPrice) {
        this.upperFixPrice = upperFixPrice;
    }

    public BigDecimal getUpperPrice() {
        return upperPrice;
    }

    public void setUpperPrice(BigDecimal upperPrice) {
        this.upperPrice = upperPrice;
    }

    public BigDecimal getUpperMoney() {
        return upperMoney;
    }

    public void setUpperMoney(BigDecimal upperMoney) {
        this.upperMoney = upperMoney;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

}
